.. _modules:

Django-admin-tools-stats Modules
================================

.. _DashboardChart:

:class:`DashboardChart`
-----------------------

Dashboard module with user registration charts.

.. _DashboardCharts:

:class:`DashboardCharts`
------------------------

Right now only dummy module with deprecation warning. We don't use module Groups any more.
